==> jc-1.4.0.tar.gz: gnu/java/nio/charset/UTF__5f16Decoder.h <==
// final class gnu.java.nio.charset.UTF_16Decoder

// class file dependencies
// @dep_class 7762b1958c717afe gnu_java_nio_charset_UTF__5f16Decoder
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4a8409777d0951e1 java_nio_charset_CharsetDecoder

// header file dependencies
// @dep_header java_nio_charset_CharsetDecoder

#include "java/nio/charset/CharsetDecoder.h"

#ifndef _JC_gnu_java_nio_charset_UTF__5f16Decoder_H_
#define _JC_gnu_java_nio_charset_UTF__5f16Decoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_refs	_jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_nonrefs	_jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$refs	_jc_gnu_java_nio_charset_UTF__5f16Decoder$refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$nonrefs	_jc_gnu_java_nio_charset_UTF__5f16Decoder$nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object	_jc_gnu_java_nio_charset_UTF__5f16Decoder$object;

typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$fields_struct	_jc_gnu_java_nio_charset_UTF__5f16Decoder$fields_struct;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vmethods	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vmethods;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtable	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vtable;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype;

// Class fields structure
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$fields_struct {
	jint	BIG__5fENDIAN;
	jint	LITTLE__5fENDIAN;
	jint	UNKNOWN__5fENDIAN;
	jchar	BYTE__5fORDER__5fMARK;
	jchar	REVERSED__5fBYTE__5fORDER__5fMARK;
};
extern _jc_gnu_java_nio_charset_UTF__5f16Decoder$fields_struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$class_fields;

// Constructors
extern void _jc_gnu_java_nio_charset_UTF__5f16Decoder$method$_init$c1df676a7942ccac(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *, struct _jc_java_nio_charset_Charset$object *, jint);

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_gnu_java_nio_charset_UTF__5f16Decoder$method$decodeLoop$5f4fe61acac11663(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *, struct _jc_java_nio_ByteBuffer$object *, struct _jc_java_nio_CharBuffer$object *);
extern void _jc_gnu_java_nio_charset_UTF__5f16Decoder$method$implReset$7614bfe5fe6326d0(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f16Decoder$method_info$decodeLoop$5f4fe61acac11663;
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f16Decoder$method_info$implReset$7614bfe5fe6326d0;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*decodeLoop$5f4fe61acac11663)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *, struct _jc_java_nio_ByteBuffer$object *, struct _jc_java_nio_CharBuffer$object *);
	void	(*implReset$7614bfe5fe6326d0)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *);
};

// Vtable
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CharsetDecoder$vmethods	java_nio_charset_CharsetDecoder;
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vmethods	gnu_java_nio_charset_UTF__5f16Decoder;
};

// Vtype
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$refs {
    _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_refs	gnu_java_nio_charset_UTF__5f16Decoder;
    _jc_java_nio_charset_CharsetDecoder$sub_refs	java_nio_charset_CharsetDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_nonrefs {
	jint	originalByteOrder;
	jint	byteOrder;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CharsetDecoder$sub_nonrefs	java_nio_charset_CharsetDecoder;
    _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_nonrefs	gnu_java_nio_charset_UTF__5f16Decoder;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object {
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype	*vtype;
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype _jc_gnu_java_nio_charset_UTF__5f16Decoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_UTF__5f16Decoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_UTF__5f16Decoder$class_object;

#endif	/* _JC_gnu_java_nio_charset_UTF__5f16Decoder_H_ */

==> jc-1.4.6.tar.gz: gnu/java/nio/charset/UTF__5f16Decoder.h <==
// final class gnu.java.nio.charset.UTF_16Decoder

// class file dependencies
// @dep_class 8d505add2da38b0a gnu_java_nio_charset_UTF__5f16Decoder
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fe28164a0cadaacb java_nio_charset_CharsetDecoder

// header file dependencies
// @dep_header java_nio_charset_CharsetDecoder

#include "java/nio/charset/CharsetDecoder.h"

#ifndef _JC_gnu_java_nio_charset_UTF__5f16Decoder_H_
#define _JC_gnu_java_nio_charset_UTF__5f16Decoder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_nio_ByteBuffer$object;
struct _jc_java_nio_CharBuffer$object;
struct _jc_java_nio_charset_Charset$object;
struct _jc_java_nio_charset_CoderResult$object;

// Typedefs
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_refs	_jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_nonrefs	_jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$refs	_jc_gnu_java_nio_charset_UTF__5f16Decoder$refs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$nonrefs	_jc_gnu_java_nio_charset_UTF__5f16Decoder$nonrefs;
typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object	_jc_gnu_java_nio_charset_UTF__5f16Decoder$object;

typedef struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$fields_struct	_jc_gnu_java_nio_charset_UTF__5f16Decoder$fields_struct;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vmethods	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vmethods;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtable	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vtable;
typedef const struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype;

// Class fields structure
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$fields_struct {
	jint	BIG__5fENDIAN;
	jint	LITTLE__5fENDIAN;
	jint	UNKNOWN__5fENDIAN;
	jchar	BYTE__5fORDER__5fMARK;
	jchar	REVERSED__5fBYTE__5fORDER__5fMARK;
};
extern _jc_gnu_java_nio_charset_UTF__5f16Decoder$fields_struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$class_fields;

// Constructors
extern void _jc_gnu_java_nio_charset_UTF__5f16Decoder$method$_init$c1df676a7942ccac(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *, struct _jc_java_nio_charset_Charset$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_nio_charset_CoderResult$object *_jc_gnu_java_nio_charset_UTF__5f16Decoder$method$decodeLoop$5f4fe61acac11663(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *, struct _jc_java_nio_ByteBuffer$object *, struct _jc_java_nio_CharBuffer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_nio_charset_UTF__5f16Decoder$method$implReset$7614bfe5fe6326d0(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f16Decoder$method_info$decodeLoop$5f4fe61acac11663;
extern _jc_method _jc_gnu_java_nio_charset_UTF__5f16Decoder$method_info$implReset$7614bfe5fe6326d0;

// Virtual methods structure
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vmethods {
	struct _jc_java_nio_charset_CoderResult$object	*(*decodeLoop$5f4fe61acac11663)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *, struct _jc_java_nio_ByteBuffer$object *, struct _jc_java_nio_CharBuffer$object *) _JC_JCNI_ATTR;
	void	(*implReset$7614bfe5fe6326d0)(_jc_env *, struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_nio_charset_CharsetDecoder$vmethods	java_nio_charset_CharsetDecoder;
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vmethods	gnu_java_nio_charset_UTF__5f16Decoder;
};

// Vtype
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype {
	_jc_type			type;
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$refs {
    _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_refs	gnu_java_nio_charset_UTF__5f16Decoder;
    _jc_java_nio_charset_CharsetDecoder$sub_refs	java_nio_charset_CharsetDecoder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_nonrefs {
	jint	originalByteOrder;
	jint	byteOrder;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_nio_charset_CharsetDecoder$sub_nonrefs	java_nio_charset_CharsetDecoder;
    _jc_gnu_java_nio_charset_UTF__5f16Decoder$sub_nonrefs	gnu_java_nio_charset_UTF__5f16Decoder;
};

// Object instance structure
struct _jc_gnu_java_nio_charset_UTF__5f16Decoder$object {
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype	*vtype;
	_jc_gnu_java_nio_charset_UTF__5f16Decoder$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_nio_charset_UTF__5f16Decoder$vtype _jc_gnu_java_nio_charset_UTF__5f16Decoder$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_nio_charset_UTF__5f16Decoder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_nio_charset_UTF__5f16Decoder$class_object;

#endif	/* _JC_gnu_java_nio_charset_UTF__5f16Decoder_H_ */
